is_pxweb_config_response: Check if a response is a pxweb config response
Description
Check if a response is a pxweb config response
Usage
is_pxweb_config_response(x, version)
Arguments
- x
a response object
- version
the version of the pxweb API to check for