Learn R Programming

pxweb (version 0.19.2)

pxweb_data_v2_c: Combine PXWEB API v2 data objects.

Description

Combines a list of pxweb_data_v2 JSON-stat2 data objects returned from split PXWEB API v2 queries. The combined object keeps the v2 data shape and rebuilds dimension indexes, labels, sizes, and values so it can be converted with as.data.frame().

Usage

pxweb_data_v2_c(x)

Value

a combined pxweb_data_v2 object.

Arguments

x

a list of pxweb_data_v2 objects.