Learn R Programming

pxweb (version 0.19.2)

pxweb_data_v2_dataset_note_comment: Construct a v2 dataset note comment.

Description

Converts a JSON-stat2 dataset-level note to an obs_comment object. Dataset notes do not point to a specific row or column, so both index positions are NA.

Usage

pxweb_data_v2_dataset_note_comment(x, comment)

Value

a pxweb_data_comment object.

Arguments

x

a pxweb_data_v2 object.

comment

a normalized comment string.