placeholder value used before the latest available value is
resolved against table metadata. The default "9999" is replaced by
the last metadata value before the v2 data request is sent.
id
codelist id, for example an aggregation id returned by a PXWEB API
v2 metadata response.
value_codes
value codes to request from the selected codelist.
output_values
whether the API should return aggregated values or
single values for the codelist.